@@ -6,16 +6,14 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-use 5.008;
 use strict;
 use warnings;
-
-package Dist::Zilla::Plugin::Test::Compile; # git description: v2.053-8-g6cedd05
-# ABSTRACT: Common tests to check syntax of your modules, only using core modules
-# KEYWORDS: plugin test compile verify validate load modules scripts
+package Dist::Zilla::Plugin::Test::Compile; # git description: v2.054-18-gc83214d
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
+# ABSTRACT: Common tests to check syntax of your modules, using only core modules
+# KEYWORDS: plugin test compile verify validate load modules scripts
 
-our $VERSION = '2.054';
+our $VERSION = '2.055';
 
 use Moose;
 use Path::Tiny;
@@ -68,8 +66,8 @@ has phase => (
     default => sub { return $_[0]->xt_mode ? 'develop' : 'test' },
 );
 
-sub mvp_multivalue_args { qw(skips files) }
-sub mvp_aliases { return { skip => 'skips', file => 'files' } }
+sub mvp_multivalue_args { qw(skips files switches) }
+sub mvp_aliases { return { skip => 'skips', file => 'files', switch => 'switches' } }
 
 has skips => (
     isa => 'ArrayRef[Str]',
@@ -87,6 +85,14 @@ has files => (
     default => sub { [] },
 );
 
+has switches => (
+    isa => 'ArrayRef[Str]',
+    traits => ['Array'],
+    handles => { switches => 'elements' },
+    lazy => 1,
+    default => sub { [] },
+);
+
 has _test_more_version => (
     is => 'ro', isa => 'Str',
     init_arg => undef,
@@ -122,6 +128,8 @@ around dump_config => sub
         skips => [ sort $self->skips ],
         (map { $_ => $self->$_ ? 1 : 0 } qw(fake_home needs_display bail_out_on_fail)),
         (map { $_ => $self->$_ } qw(filename fail_on_warning bail_out_on_fail phase)),
+        switch => [ $self->switches ],
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
     return $config;
 };
@@ -134,8 +142,8 @@ sub register_prereqs
 
     $self->zilla->register_prereqs(
         {
-            type  => 'requires',
             phase => $self->phase,
+            type  => 'requires',
         },
         'Test::More' => $self->_test_more_version,
         'File::Spec' => '0',
@@ -210,6 +218,7 @@ sub munge_file
                     $self->fail_on_warning eq 'author' && $self->filename =~ m{^xt/author/}
                     ? 'all'
                     : $self->fail_on_warning),
+                switches => \[$self->switches],
             }
         )
     );
@@ -238,6 +247,7 @@ __PACKAGE__->meta->make_immutable;
 #pod     needs_display = 1
 #pod     fail_on_warning = author
 #pod     bail_out_on_fail = 1
+#pod     switch = -M-warnings=numeric    ; like "no warnings 'numeric'
 #pod
 #pod =head1 DESCRIPTION
 #pod
@@ -347,6 +357,16 @@ __PACKAGE__->meta->make_immutable;
 #pod When true, the default C<filename> becomes F<xt/author/00-compile.t> and the
 #pod default C<dependency> phase becomes C<develop>.
 #pod
+#pod =head2 C<switch>
+#pod
+#pod Use this option to pass a command-line switch (e.g. C<-d:Confess>, C<-M-warnings=numeric>) to the command that
+#pod tests the module or script. Can be used more than once.  See L<perlrun> for more on constructing these switches.
+#pod
+#pod =head1 RUNTIME ENVIRONMENT OPTIONS
+#pod
+#pod If the environment variable C<$PERL_COMPILE_TEST_DEBUG> is set to a true option when the test is run, the command
+#pod to test each file will be printed as a C<diag>.
+#pod
 #pod =head1 SEE ALSO
 #pod
 #pod =for :list
@@ -361,11 +381,11 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Test::Compile - Common tests to check syntax of your modules, only using core modules
+Dist::Zilla::Plugin::Test::Compile - Common tests to check syntax of your modules, using only core modules
 
 =head1 VERSION
 
-version 2.054
+version 2.055
 
 =head1 SYNOPSIS
 
@@ -377,6 +397,7 @@ In your F<dist.ini>:
     needs_display = 1
     fail_on_warning = author
     bail_out_on_fail = 1
+    switch = -M-warnings=numeric    ; like "no warnings 'numeric'
 
 =head1 DESCRIPTION
 
@@ -492,6 +513,16 @@ files are properly marked as executables for the installer.
 When true, the default C<filename> becomes F<xt/author/00-compile.t> and the
 default C<dependency> phase becomes C<develop>.
 
+=head2 C<switch>
+
+Use this option to pass a command-line switch (e.g. C<-d:Confess>, C<-M-warnings=numeric>) to the command that
+tests the module or script. Can be used more than once.  See L<perlrun> for more on constructing these switches.
+
+=head1 RUNTIME ENVIRONMENT OPTIONS
+
+If the environment variable C<$PERL_COMPILE_TEST_DEBUG> is set to a true option when the test is run, the command
+to test each file will be printed as a C<diag>.
+
 =head1 SEE ALSO
 
 =over 4
@@ -506,6 +537,17 @@ L<Test::Script>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Test-Compile>
+(or L<bug-Dist-Zilla-Plugin-Test-Compile@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Test-Compile@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 =head1 AUTHORS
 
 =over 4
@@ -522,7 +564,7 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Ahmad M. Zawawi Olivier Mengué Kent Fredric Randy Stauner Jesse Luehrs Harley Pig David Golden Graham Knop fayland Peter Shangov Chris Weyl Ricardo SIGNES Marcel Gruenauer
+=for stopwords Ahmad M. Zawawi Olivier Mengué Kent Fredric Jesse Luehrs David Golden Randy Stauner Harley Pig Graham Knop fayland Peter Shangov Chris Weyl Ricardo SIGNES Marcel Gruenauer
 
 =over 4
 
@@ -540,19 +582,19 @@ Kent Fredric <kentnl@cpan.org>
 
 =item *
 
-Randy Stauner <rwstauner@cpan.org>
-
-=item *
-
 Jesse Luehrs <doy@tozt.net>
 
 =item *
 
-Harley Pig <harleypig@gmail.com>
+David Golden <dagolden@cpan.org>
 
 =item *
 
-David Golden <dagolden@cpan.org>
+Randy Stauner <rwstauner@cpan.org>
+
+=item *
+
+Harley Pig <harleypig@gmail.com>
 
 =item *
 
@@ -580,7 +622,7 @@ Marcel Gruenauer <hanekomu@gmail.com>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2009 by Jérôme Quelin.
 
@@ -595,7 +637,7 @@ use 5.006;
 use strict;
 use warnings;
 
-# this test was generated with {{ ref($plugin) . ' ' . $plugin->VERSION }}
+# this test was generated with {{ ref $plugin }} {{ $plugin->VERSION }}
 
 use Test::More{{ $test_more_version ? " $test_more_version" : '' }};
 {{
@@ -633,7 +675,9 @@ local $ENV{HOME} = File::Temp::tempdir( CLEANUP => 1 );
 CODE
 }}
 
-my $inc_switch = -d 'blib' ? '-Mblib' : '-Ilib';
+my @switches = (
+    -d 'blib' ? '-Mblib' : '-Ilib',
+{{ @$switches ? '    ' . join(' ', map { q{'} . $_ . q{',} } @$switches) . "\n" : '' }});
 
 use File::Spec;
 use IPC::Open3;
@@ -647,7 +691,10 @@ for my $lib (@module_files)
     # see L<perlfaq8/How can I capture STDERR from an external command?>
     my $stderr = IO::Handle->new;
 
-    my $pid = open3($stdin, '>&STDERR', $stderr, $^X, $inc_switch, '-e', "require q[$lib]");
+    diag('Running: ', join(', ', $^X, @switches, '-e\'', "require q[$lib]", '\''))
+        if $ENV{PERL_COMPILE_TEST_DEBUG};
+
+    my $pid = open3($stdin, '>&STDERR', $stderr, $^X, @switches, '-e', "require q[$lib]");
     binmode $stderr, ':crlf' if $^O eq 'MSWin32';
     my @_warnings = <$stderr>;
     waitpid($pid, 0);
@@ -671,11 +718,14 @@ foreach my $file (@scripts)
     my $line = <$fh>;
 
     close $fh and skip("$file isn't perl", 1) unless $line =~ /^#!\s*(?:\S*perl\S*)((?:\s+-\w*)*)(?:\s*#.*)?$/;
-    my @flags = $1 ? split(' ', $1) : ();
+    @switches = (@switches, split(' ', $1)) if $1;
 
     my $stderr = IO::Handle->new;
 
-    my $pid = open3($stdin, '>&STDERR', $stderr, $^X, $inc_switch, @flags, '-c', $file);
+    diag('Running: ', join(', ', $^X, @switches, '-c', $file))
+        if $ENV{PERL_COMPILE_TEST_DEBUG};
+
+    my $pid = open3($stdin, '>&STDERR', $stderr, $^X, @switches, '-c', $file);
     binmode $stderr, ':crlf' if $^O eq 'MSWin32';
     my @_warnings = <$stderr>;
     waitpid($pid, 0);
